@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import logging
-import re
-from constants import *
+from nameparser import u, text_type
+from nameparser.constants import *
 
 # http://code.google.com/p/python-nameparser/issues/detail?id=10
 log = logging.getLogger('HumanName')
@@ -16,19 +16,23 @@ log.setLevel(logging.ERROR)
 
 ENCODING = 'utf-8'
 
+
 def lc(value):
-    '''Lower case and remove any periods to normalize for comparison.'''
+    """Lower case and remove any periods to normalize for comparison."""
     if not value:
         return u''
     return value.lower().replace('.','')
 
+
 def is_an_initial(value):
     return re_initial.match(value) or False
 
+
 class BlankHumanNameError(AttributeError):
     # deprecated in v0.2.5, no longer used
     pass
 
+
 class HumanName(object):
     
     """
@@ -76,25 +80,28 @@ class HumanName(object):
         HumanName instances are equal to other objects whose 
         lower case unicode representations are the same
         """
-        return unicode(self).lower() == unicode(other).lower()
+        return (u(self)).lower() == (u(other)).lower()
     
     def __ne__(self, other):
-        return not unicode(self).lower() == unicode(other).lower()
+        return not (u(self)).lower() == (u(other)).lower()
     
     def __getitem__(self, key):
         if isinstance(key, slice):
             return [getattr(self, x) for x in self._members[key]]
         else:
             return getattr(self, self._members[key])
-    
+
     def next(self):
+        return self.__next__()
+
+    def __next__(self):
         if self.count >= len(self._members):
             self.count = 0
             raise StopIteration
         else:
             c = self.count
             self.count = c + 1
-            return getattr(self, self._members[c]) or self.next()
+            return getattr(self, self._members[c]) or next(self)
 
     def __unicode__(self):
         if self.string_format:
@@ -103,7 +110,7 @@ class HumanName(object):
         return u" ".join(self)
     
     def __str__(self):
-        return self.__unicode__().encode(self.ENCODING)
+        return self.__unicode__()
     
     def __repr__(self):
         if self.unparsable:
@@ -216,13 +223,13 @@ class HumanName(object):
         """
         ps = []
         for part in parts:
-            ps += map(lambda x: x.strip(' ,'), part.split(' '))
+            ps += [x.strip(' ,') for x in part.split(' ')]
         
         # if there is a period that is not at the end of a piece, split it on periods
         pieces = []
         for piece in ps:
             if piece[:-1].find('.') >= 0:
-                p = filter(None, piece.split('.'))
+                p = [_f for _f in piece.split('.') if _f]
                 pieces += [x+'.' for x in p]
             else:
                 pieces += [piece]
@@ -235,7 +242,7 @@ class HumanName(object):
             # loop through the pieces backwards, starting at the end of the list.
             # Join conjunctions to the pieces on either side of them.
             
-            if len(conj) == 1 and len(filter(self.is_rootname, pieces)) + additional_parts_count < 4:
+            if len(conj) == 1 and len(list(filter(self.is_rootname, pieces))) + additional_parts_count < 4:
                 # if there are only 3 total parts (minus known titles, suffixes and prefixes) 
                 # and this conjunction is a single letter, prefer treating it as an initial
                 # rather than a conjunction.
@@ -244,7 +251,7 @@ class HumanName(object):
             
             try:
                 i = pieces.index((conj))
-            except ValueError, e:
+            except ValueError:
                 log.error("Couldn't find '{conj}' in pieces. i={i}, pieces={pieces}".format(**locals()))
                 continue
             
@@ -280,7 +287,7 @@ class HumanName(object):
                 pieces.pop(i)
         
         # join prefices to following lastnames: ['de la Vega'], ['van Buren']
-        prefixes = filter(self.is_prefix, pieces)
+        prefixes = list(filter(self.is_prefix, pieces))
         try:
             for prefix in prefixes:
                 try:
@@ -290,7 +297,7 @@ class HumanName(object):
                     # extra work to find the index the second time around
                     def find_p(p):
                         return p.endswith(prefix) # closure on prefix
-                    m = filter(find_p, pieces)
+                    m = list(filter(find_p, pieces))
                     # I wonder if some input will throw an IndexError here. 
                     # Means it can't find prefix anyore.
                     i = pieces.index(m[0])
@@ -299,7 +306,7 @@ class HumanName(object):
         except IndexError:
             pass
             
-        log.debug(u"pieces: " + unicode(pieces))
+        log.debug(u"pieces: {0}".format(pieces))
         return pieces
     
     def _parse_full_name(self):
@@ -307,8 +314,8 @@ class HumanName(object):
         Parse full name into the buckets
         """
         
-        if not isinstance(self._full_name, unicode):
-            self._full_name = unicode(self._full_name, self.ENCODING)
+        if not isinstance(self._full_name, text_type):
+            self._full_name = u(self._full_name, self.ENCODING)
         
         # collapse multiple spaces
         self._full_name = re.sub(re_spaces, u" ", self._full_name.strip() )
@@ -319,8 +326,8 @@ class HumanName(object):
         # break up full_name by commas
         parts = [x.strip() for x in self._full_name.split(",")]
         
-        log.debug(u"full_name: " + self._full_name)
-        log.debug(u"parts: " + unicode(parts))
+        log.debug(u"full_name: {0}".format(self._full_name))
+        log.debug(u"parts: {0}".format(parts))
         
         if len(parts) == 1:
             
@@ -358,7 +365,7 @@ class HumanName(object):
                 self.suffix_list += parts[1:]
                 
                 pieces = self._parse_pieces(parts[0].split(' '))
-                log.debug(u"pieces: " + unicode(pieces))
+                log.debug(u"pieces: {0}".format(u(pieces)))
                 
                 for i, piece in enumerate(pieces):
                     try:
@@ -381,7 +388,7 @@ class HumanName(object):
                 # lastname comma: last, title first middles[,] suffix [,suffix]
                 pieces = self._parse_pieces(parts[1].split(' '), 1)
                 
-                log.debug(u"pieces: " + unicode(pieces))
+                log.debug(u"pieces: {0}".format(u(pieces)))
                 
                 self.last_list.append(parts[0])
                 for i, piece in enumerate(pieces):
@@ -445,16 +452,16 @@ class HumanName(object):
         
             >>> name = HumanName('bob v. de la macdole-eisenhower phd')
             >>> name.capitalize()
-            >>> unicode(name)
+            >>> u(name)
             u'Bob V. de la MacDole-Eisenhower Ph.D.'
             >>> # Don't touch good names
             >>> name = HumanName('Shirley Maclaine')
             >>> name.capitalize()
-            >>> unicode(name) 
+            >>> u(name) 
             u'Shirley Maclaine'
         
         """
-        name = unicode(self)
+        name = u(self)
         if not (name == name.upper() or name == name.lower()):
             return
         self.title_list = self.cap_piece(self.title).split(' ')
